﻿using MindFusion.Diagramming.Wpf;
using MindFusion.Diagramming.Wpf.Export;
using System.IO;
using System.Windows;
using System.Windows.Media;

namespace SvgExportIssues;

/// <summary>
/// Interaction logic for MainWindow.xaml
/// </summary>
	public partial class MainWindow : Window
{
    public MainWindow()
    {
        InitializeComponent();

        diagram.DefaultShape = Shapes.Rectangle;
        diagram.Bounds = new Rect(0, 0, 3840, 3840);

        radioButton1.IsChecked = true;

        diagram.NodeEffects.Add(new GlassEffect());
        diagram.NodeEffects.Add(new AeroEffect());

        Style shapeNodeStyle = new Style();
        shapeNodeStyle.Setters.Add(new Setter(ShapeNode.BrushProperty,
            new LinearGradientBrush(Colors.LightGray, Colors.DarkTurquoise, 80)));
        shapeNodeStyle.Setters.Add(new Setter(ShapeNode.FontSizeProperty, 10.75));
        diagram.ShapeNodeStyle = shapeNodeStyle;

        ShapeNode pb1, pb2, pb3, pb4, decb1, decb2;

        apat1 = new AnchorPattern(new AnchorPoint[]
            {
                new AnchorPoint(50, 0, true, true),
                new AnchorPoint(100, 50, true, true),
                new AnchorPoint(50, 100, true, true),
                new AnchorPoint(0, 50, true, true)
            });

        apat2 = new AnchorPattern(new AnchorPoint[]
            {
                new AnchorPoint(10, 0, true, false, MarkStyle.Circle, Brushes.RoyalBlue),
                new AnchorPoint(50, 0, true, false, MarkStyle.Circle, Brushes.Blue),
                new AnchorPoint(90, 0, true, false, MarkStyle.Circle, Brushes.Firebrick),
                new AnchorPoint(10, 100, false, true, MarkStyle.Rectangle),
                new AnchorPoint(50, 100, false, true, MarkStyle.Rectangle),
                new AnchorPoint(90, 100, false, true, MarkStyle.Rectangle),
                new AnchorPoint(0, 50, true, true, MarkStyle.Custom)
            });

        var textNode = new TextNode();
        textNode.Bounds = new Rect(1, 0, 500, 500);
        diagram.Nodes.Add(textNode);

        var rectNode = new RectangleNode();
        rectNode.Bounds = new Rect(125, 135, 185, 75);
        diagram.Nodes.Add(rectNode);

        var router = diagram.LinkRouter as QuickRouter;
        if (router != null)
            router.UBendMaxLen = 10;
        diagram.RoutingOptions.TriggerRerouting |= RerouteLinks.WhileCreating;
        diagram.RoutingOptions.Anchoring = Anchoring.Keep;
    }

    private void SaveToSvg()
    {
        var exporter = new SvgExporter();
        using var svgStream = new MemoryStream();
        exporter.InvisibleItems = false;
        exporter.Export(diagram, svgStream);
        svgStream.Seek(0, SeekOrigin.Begin);
        using FileStream fileStream = File.Create($"C:\\temp\\test.svg");
        svgStream.CopyTo(fileStream);
    }

    private void radioButton1_Checked(object sender, RoutedEventArgs e)
    {
        diagram.DefaultShape = Shapes.Rectangle;
    }

    private void radioButton2_Checked(object sender, RoutedEventArgs e)
    {
        diagram.DefaultShape = Shapes.Decision;
    }

    private void diagram_NodeCreated(object sender, NodeEventArgs e)
    {
        ShapeNode node = e.Node as ShapeNode;
        if (node == null)
            return;

        if (node.Shape == Shapes.Decision)
            node.AnchorPattern = AnchorPattern.Decision1In3Out;
        else
            node.AnchorPattern = apat2;
    }

    private void OnLoadClick(object sender, RoutedEventArgs e)
    {
        Microsoft.Win32.OpenFileDialog openDlg = new Microsoft.Win32.OpenFileDialog();
        if (openDlg.ShowDialog() == true)
            diagram.LoadFromXml(openDlg.FileName);
    }   

    private void OnSaveClick(object sender, RoutedEventArgs e)
    {
        SaveToSvg();
    }

    private AnchorPattern apat1;
    private AnchorPattern apat2;
}
